==> crisis-management-resources-v0.2-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureImplementationManager.java <==
package org.petalslink.officeofinfrastructure;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import org.petalslink.officeofinfrastructure.OfficeOfInfrastructure;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/v3/OfficeOfInfrastructure.wsdl",
	targetNamespace = "http://www.petalslink.org/OfficeOfInfrastructure/",
	endpointInterface = "org.petalslink.officeofinfrastructure.OfficeOfInfrastructure",
	portName = "OfficeOfInfrastructureSOAPEndpoint",
	serviceName = "OfficeOfInfrastructure")
public class OfficeOfInfrastructureImplementationManager extends AbstractImplementationManager<OfficeOfInfrastructure> implements OfficeOfInfrastructure{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public OfficeOfInfrastructureImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new OfficeOfInfrastructure_EventProducerNotifier(this.getConfiguration(), context);
	}

	public OfficeOfInfrastructureImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new OfficeOfInfrastructure_EventProducerNotifier(this.getConfiguration(), context);
	}

	public org.petalslink.officeofinfrastructure.ReceiveResourcesResponse receiveResources(ReceiveResources parameters)  {
		org.petalslink.officeofinfrastructure.ReceiveResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("receiveResources" ,parameters);
		response = this.getTestImplementation().receiveResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "receiveResources", parameters, response, org.petalslink.officeofinfrastructure.ReceiveResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ReceiveResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("receiveResources" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse reportOnTheImplementationOfTheCirculationPlan(ReportOnTheImplementationOfTheCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("reportOnTheImplementationOfTheCirculationPlan" ,parameters);
		response = this.getTestImplementation().reportOnTheImplementationOfTheCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "reportOnTheImplementationOfTheCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("reportOnTheImplementationOfTheCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse analyseCirculationPlan(AnalyseCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("analyseCirculationPlan" ,parameters);
		response = this.getTestImplementation().analyseCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "analyseCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("analyseCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.AskForResourcesResponse askForResources(AskForResources parameters)  {
		org.petalslink.officeofinfrastructure.AskForResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("askForResources" ,parameters);
		response = this.getTestImplementation().askForResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "askForResources", parameters, response, org.petalslink.officeofinfrastructure.AskForResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.AskForResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("askForResources" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse implementCirculationPlan(ImplementCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("implementCirculationPlan" ,parameters);
		response = this.getTestImplementation().implementCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "implementCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("implementCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse informCrisisCellOfIssues(InformCrisisCellOfIssues parameters)  {
		org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("informCrisisCellOfIssues" ,parameters);
		response = this.getTestImplementation().informCrisisCellOfIssues(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "informCrisisCellOfIssues", parameters, response, org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("informCrisisCellOfIssues" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse consultStatusOfResources(ConsultStatusOfResources parameters)  {
		org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("consultStatusOfResources" ,parameters);
		response = this.getTestImplementation().consultStatusOfResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "consultStatusOfResources", parameters, response, org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("consultStatusOfResources" ,parameters, response);
		return response;
	}



}

==> crisis-management-resources-v0.5-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureImplementationManager.java <==
package org.petalslink.officeofinfrastructure;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import org.petalslink.officeofinfrastructure.OfficeOfInfrastructure;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/management/generated/OfficeOfInfrastructure.wsdl",
	targetNamespace = "http://www.petalslink.org/OfficeOfInfrastructure/",
	endpointInterface = "org.petalslink.officeofinfrastructure.OfficeOfInfrastructure",
	portName = "OfficeOfInfrastructureSOAPEndpoint",
	serviceName = "OfficeOfInfrastructure")
public class OfficeOfInfrastructureImplementationManager extends AbstractImplementationManager<OfficeOfInfrastructure> implements OfficeOfInfrastructure{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public OfficeOfInfrastructureImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new OfficeOfInfrastructure_EventProducerNotifier(this.getConfiguration(), context);
	}

	public OfficeOfInfrastructureImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new OfficeOfInfrastructure_EventProducerNotifier(this.getConfiguration(), context);
	}

	public org.petalslink.officeofinfrastructure.ReceiveResourcesResponse receiveResources(ReceiveResources parameters)  {
		org.petalslink.officeofinfrastructure.ReceiveResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("receiveResources" ,parameters);
		response = this.getTestImplementation().receiveResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "receiveResources", parameters, response, org.petalslink.officeofinfrastructure.ReceiveResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ReceiveResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("receiveResources" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse reportOnTheImplementationOfTheCirculationPlan(ReportOnTheImplementationOfTheCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("reportOnTheImplementationOfTheCirculationPlan" ,parameters);
		response = this.getTestImplementation().reportOnTheImplementationOfTheCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "reportOnTheImplementationOfTheCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ReportOnTheImplementationOfTheCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("reportOnTheImplementationOfTheCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse analyseCirculationPlan(AnalyseCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("analyseCirculationPlan" ,parameters);
		response = this.getTestImplementation().analyseCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "analyseCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.AnalyseCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("analyseCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.AskForResourcesResponse askForResources(AskForResources parameters)  {
		org.petalslink.officeofinfrastructure.AskForResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("askForResources" ,parameters);
		response = this.getTestImplementation().askForResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "askForResources", parameters, response, org.petalslink.officeofinfrastructure.AskForResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.AskForResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("askForResources" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse implementCirculationPlan(ImplementCirculationPlan parameters)  {
		org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("implementCirculationPlan" ,parameters);
		response = this.getTestImplementation().implementCirculationPlan(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "implementCirculationPlan", parameters, response, org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ImplementCirculationPlanResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("implementCirculationPlan" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse informCrisisCellOfIssues(InformCrisisCellOfIssues parameters)  {
		org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("informCrisisCellOfIssues" ,parameters);
		response = this.getTestImplementation().informCrisisCellOfIssues(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "informCrisisCellOfIssues", parameters, response, org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.InformCrisisCellOfIssuesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("informCrisisCellOfIssues" ,parameters, response);
		return response;
	}


	public org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse consultStatusOfResources(ConsultStatusOfResources parameters)  {
		org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("consultStatusOfResources" ,parameters);
		response = this.getTestImplementation().consultStatusOfResources(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("OfficeOfInfrastructure", "OfficeOfInfrastructureSOAPEndpoint", "consultStatusOfResources", parameters, response, org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (org.petalslink.officeofinfrastructure.ConsultStatusOfResourcesResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("consultStatusOfResources" ,parameters, response);
		return response;
	}



}
